Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2490)

Unified Diff: chrome/browser/resources/settings/search_settings.js

Issue 2259423002: Settings Search: Make tooltip vertical. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/resources/settings/settings_shared_css.html » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/resources/settings/search_settings.js
diff --git a/chrome/browser/resources/settings/search_settings.js b/chrome/browser/resources/settings/search_settings.js
index 50e805ea78b78cf00b30f9bbf0d07da11d8c9d3e..740bc77808f92789e0e4f05d2eb1fccd6be91b3d 100644
--- a/chrome/browser/resources/settings/search_settings.js
+++ b/chrome/browser/resources/settings/search_settings.js
@@ -195,9 +195,9 @@ cr.define('settings', function() {
searchBubble.appendChild(innards);
element.appendChild(searchBubble);
- // Dynamically position the bubble at the edge the associated controle
- // elemnt.
- searchBubble.style.left = '-' + searchBubble.offsetWidth + 'px';
+ // Dynamically position the bubble at the edge the associated control
+ // element.
+ searchBubble.style.top = element.offsetTop + element.offsetHeight + 'px';
}
/**
« no previous file with comments | « no previous file | chrome/browser/resources/settings/settings_shared_css.html » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698